import { createRouter, createWebHashHistory, RouteRecordRaw } from "vue-router";

export const Layout = () => import("@/layout/index.vue");

// 静态路由
export const constantRoutes: RouteRecordRaw[] = [
  {
    path: "/",
    name: "/",
    component: Layout,
    redirect: "/dashboard",
    children: [
      {
        path: "dashboard",
        component: () => import("@/views/dashboard/index.vue"),
        name: "Dashboard", // 用于 keep-alive, 必须与SFC自动推导或者显示声明的组件name一致
        meta: {
          title: "dashboard",
          icon: "homepage",
          affix: true,
          hidden: true,
          keepAlive: true,
          alwaysShow: false,
        },
      },
    ],
  },
  {
    path: "/manageSystem/project",
    component: Layout,
    redirect: "/manageSystem/project/",
    meta: { title: "项目管理", icon: "system" }, // 一级菜单
    children: [
      {
        path: "ProjectEstablishment",
        component: () =>
          import("@/views/manageSystem/project/ProjectEstablishment/index.vue"),
        name: "UserManagement",
        meta: { title: "立项报备", icon: "system" }, // 二级菜单
      },
      {
        path: "ProjectEstablishmentDetails",
        component: () =>
          import(
            "@/views/manageSystem/project/ProjectEstablishment/details.vue"
          ),
        name: "ProjectEstablishmentDetails",
        meta: { title: "立项报备表单", icon: "system" }, // 二级菜单
      },
      {
        path: "followUp",
        component: () =>
          import("@/views/manageSystem/project/followUp/index.vue"),
        name: "followUp",
        meta: { title: "跟进洽谈", icon: "system" }, // 二级菜单
      },
      {
        path: "tender",
        component: () =>
          import("@/views/manageSystem/project/tender/index.vue"),
        name: "tender",
        meta: { title: "投标准备", icon: "system" }, // 二级菜单
      },
    ],
  },
  {
    path: "/redirect",
    component: Layout,
    meta: { hidden: true },
    children: [
      {
        path: "/redirect/:path(.*)",
        component: () => import("@/views/redirect/index.vue"),
      },
    ],
  },

  {
    path: "/login",
    component: () => import("@/views/login/index.vue"),
    meta: { hidden: true },
  },
];

/**
 * 创建路由
 */
const router = createRouter({
  history: createWebHashHistory(),
  routes: constantRoutes as RouteRecordRaw[],
  // 刷新时，滚动条位置还原
  scrollBehavior: () => ({ left: 0, top: 0 }),
});

/**
 * 重置路由
 */
export function resetRouter() {
  router.replace({ path: "/login" });
}

export default router;
